//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Beam/GrazingScanItem.cpp
//! @brief     Implements class GrazingScanItem.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Beam/GrazingScanItem.h"
#include "Base/Axis/Frame.h"
#include "Base/Axis/Scale.h"
#include "Base/Const/Units.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Axis/PointwiseAxisItem.h"
#include "GUI/Model/Beam/DistributionItems.h"

namespace {
namespace Tag {

const QString UniformAxis("UniformAxis");
const QString ListScan("ListScan");
const QString PointwiseAxis("PointwiseAxis"); // used in pre-21
const QString BeamInclinationDistribution("BeamInclinationDistribution");
const QString IsUniformAxis("IsUniformAxis");
const QString BaseData("BaseData");

} // namespace Tag
} // namespace


GrazingScanItem::GrazingScanItem()
    : BeamDistributionItem()
{
    m_distribution.simpleInit("Distribution", "", DistributionCatalog::Type::None);
}

GrazingScanItem::~GrazingScanItem() = default;

void GrazingScanItem::writeTo(QXmlStreamWriter* w) const
{
    XML::writeBaseElement<BeamDistributionItem>(w, XML::Tag::BaseData, this);
}

void GrazingScanItem::readFrom(QXmlStreamReader* r)
{
    while (r->readNextStartElement()) {
        QString tag = r->name().toString();
        if (tag == Tag::BaseData)
            XML::readBaseElement<BeamDistributionItem>(r, tag, this);
        else
            r->skipCurrentElement();
    }
}

double GrazingScanItem::scaleFactor() const
{
    return Units::deg;
}
